@@ -77,8 +77,6 @@ char *do_browser(char *path)
 		present_name = mallocstrcpy(present_name, filelist[selected]);
 	}
 
-	assert(path != NULL && path[strlen(path) - 1] == '/');
-
 	if (dir != NULL) {
 		/* Get the file list, and set longest and width in the process. */
 		read_the_list(path, dir);
@@ -223,11 +221,9 @@ char *do_browser(char *path)
 			selected = filelist_len - 1;
 		} else if (func == goto_dir_void) {
 			/* Ask for the directory to go to. */
-			int i = do_prompt(TRUE, FALSE, MGOTODIR, NULL, NULL,
-						/* TRANSLATORS: This is a prompt. */
-						browser_refresh, _("Go To Directory"));
-
-			if (i < 0) {
+			if (do_prompt(TRUE, FALSE, MGOTODIR, NULL, NULL,
+							/* TRANSLATORS: This is a prompt. */
+							browser_refresh, _("Go To Directory")) < 0) {
 				statusbar(_("Cancelled"));
 				continue;
 			}
@@ -305,13 +301,12 @@ char *do_browser(char *path)
 		} else if (func == (functionptrtype)implant) {
 			implant(first_sc_for(MBROWSER, func)->expansion);
 #endif
-		} else if (func == do_exit) {
-			/* Exit from the file browser. */
-			break;
 #ifndef NANO_TINY
 		} else if (kbinput == KEY_WINCH) {
-			;
+			;  /* Nothing to do. */
 #endif
+		} else if (func == do_exit) {
+			break;
 		} else
 			unbound_key(kbinput);
 
@@ -394,13 +389,11 @@ void read_the_list(const char *path, DIR *dir)
 	const struct dirent *nextdir;
 	size_t i = 0, path_len = strlen(path);
 
-	assert(path != NULL && path[strlen(path) - 1] == '/' && dir != NULL);
-
 	longest = 0;
 
 	/* Find the length of the longest filename in the current folder. */
 	while ((nextdir = readdir(dir)) != NULL) {
-		size_t name_len = strlenpt(nextdir->d_name);
+		size_t name_len = breadth(nextdir->d_name);
 
 		if (name_len > longest)
 			longest = name_len;
@@ -445,8 +438,6 @@ void read_the_list(const char *path, DIR *dir)
 	 * filelist, so record it. */
 	filelist_len = i;
 
-	assert(filelist != NULL);
-
 	/* Sort the list of names. */
 	qsort(filelist, filelist_len, sizeof(char *), diralphasort);
 
@@ -518,7 +509,7 @@ void browser_refresh(void)
 		struct stat st;
 		const char *thename = tail(filelist[i]);
 				/* The filename we display, minus the path. */
-		size_t namelen = strlenpt(thename);
+		size_t namelen = breadth(thename);
 				/* The length of the filename in columns. */
 		size_t infolen;
 				/* The length of the file information in columns. */
@@ -598,7 +589,7 @@ void browser_refresh(void)
 		}
 
 		/* Make sure info takes up no more than infomaxlen columns. */
-		infolen = strlenpt(info);
+		infolen = breadth(info);
 		if (infolen > infomaxlen) {
 			info[actual_x(info, infomaxlen)] = '\0';
 			infolen = infomaxlen;
@@ -672,7 +663,7 @@ int filesearch_init(bool forwards)
 		thedefault = charalloc(strlen(disp) + 7);
 		/* We use (COLS / 3) here because we need to see more on the line. */
 		sprintf(thedefault, " [%s%s]", disp,
-				(strlenpt(last_search) > COLS / 3) ? "..." : "");
+				(breadth(last_search) > COLS / 3) ? "..." : "");
 		free(disp);
 	} else
 		thedefault = mallocstrcpy(NULL, "");
